Class: RuboCop::FactoryBot::Cop::Generator Private

Inherits:
Cop::Generator
  • Object
show all
Defined in:
lib/rubocop/factory_bot/cop/generator.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Source and spec generator for new cops

This generator will take a cop name and generate a source file and spec file when given a valid qualified cop name.

API:

  • private

Instance Method Summary collapse

Instance Method Details

#todoObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



12
13
14
15
16
17
18
19
20
21
# File 'lib/rubocop/factory_bot/cop/generator.rb', line 12

def todo
  <<~TODO
    Do 4 steps:
      1. Modify the description of #{badge} in config/default.yml
      2. Implement your new cop in the generated file!
      3. Add an entry about new cop to CHANGELOG.md
      4. Commit your new cop with a message such as
         e.g. "Add new `#{badge}` cop"
  TODO
end